"""
STAC label extension module
"""

from .base import LabelExtensionObject
from .image_name_labeler import ImageNameLabeler
from .scaneo import ScaneoLabeler
